@@ -209,9 +209,10 @@ start.values.gllvm.TMB <- function(y, X = NULL, TR=NULL, family,
           inter <- rep(0, num.T * num.X)
           B <- c(env,trait,inter)
         }
+        params <- cbind(fit.mva$params$beta0, fit.mva$params$Xcoef, fit.mva$params$theta)
         fit.mva$phi <- apply(fit.mva$residuals,2,sd)
       }
-      params <- t(fit.mva$coef)
+      #params <- t(fit.mva$coef) #!!
     } else {
       fit.mva<-list()
       fit.mva$phi <- rep(1, p)
@@ -327,6 +328,14 @@ start.values.gllvm.TMB <- function(y, X = NULL, TR=NULL, family,
       params[,(ncol(params) - num.lv + 1):ncol(params)] <- t(t(gamma.new)*sig)
       index <- t(t(index)*sig)}, silent = TRUE)
   }
+  
+  if(num.lv == 0){
+    qqs <- quantile(params)
+    uppout <- qqs[4] + (qqs[4]- qqs[2])*2
+    lowout <- qqs[2] - (qqs[4]- qqs[2])*2
+    params[params < lowout] <- lowout
+    params[params > uppout] <- uppout
+  }
 
   out$params <- params
   out$phi <- phi
